@@ -16,9 +16,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ev-document-misc.h 3240 2008-10-27 12:17:08Z chpe $
+ *  $Id: ev-document-misc.h 3381 2009-01-25 15:08:57Z chpe $
  */
 
+#if !defined (__EV_EVINCE_DOCUMENT_H_INSIDE__) && !defined (EVINCE_COMPILATION)
+#error "Only <evince-document.h> can be included directly."
+#endif
+
 #ifndef EV_DOCUMENT_MISC_H
 #define EV_DOCUMENT_MISC_H
 
