@@ -37,9 +37,8 @@
 #include <libnautilus-extension/nautilus-extension-types.h>
 #include <libnautilus-extension/nautilus-property-page-provider.h>
 
+#include <evince-document.h>
 #include "ev-properties-view.h"
-#include "ev-backends-manager.h"
-#include "ev-document-factory.h"
 
 static GType epp_type = 0;
 static void property_page_provider_iface_init
@@ -134,17 +133,13 @@ nautilus_module_initialize (GTypeModule *module)
 	ev_properties_plugin_register_type (module);
 	ev_properties_view_register_type (module);
 
-	/* set up translation catalog */
-	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
-	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-
-	ev_backends_manager_init ();
+        ev_init ();
 }
 
 void
 nautilus_module_shutdown (void)
 {
-	ev_backends_manager_shutdown ();
+        ev_shutdown ();
 }
 
 void
@@ -157,4 +152,3 @@ nautilus_module_list_types (const GType **types,
 	*types = type_list;
 	*num_types = G_N_ELEMENTS (type_list);
 }
-
