@@ -22,12 +22,15 @@
 
 #include <config.h>
 
+#include <stdlib.h>
 #include <string.h>
 
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
+#ifdef GDK_WINDOWING_X11
 #include <gdk/gdkx.h>
+#endif
 
 #include "totem-scrsaver.h"
 #include "eggsmclient.h"
@@ -35,6 +38,7 @@
 #include "ev-application.h"
 #include "ev-document-factory.h"
 #include "ev-file-helpers.h"
+#include "ev-metadata-manager.h"
 #include "ev-utils.h"
 
 #ifdef ENABLE_DBUS
@@ -52,8 +56,8 @@ static void ev_application_save_print_settings      (EvApplication *application)
 struct _EvApplication {
 	GObject base_instance;
 
+	gchar *dot_dir;
 	gchar *accel_map_file;
-	
 	gchar *toolbars_file;
 
 	EggToolbarsModel *toolbars_model;
@@ -77,6 +81,8 @@ struct _EvApplicationClass {
 	GObjectClass base_class;
 };
 
+static EvApplication *instance;
+
 G_DEFINE_TYPE (EvApplication, ev_application, G_TYPE_OBJECT);
 
 #define APPLICATION_SERVICE_NAME "org.gnome.evince.ApplicationService"
@@ -133,7 +139,9 @@ ev_application_register_service (EvApplication *application)
                                              G_OBJECT (application));
 	
 	application->scr_saver = totem_scrsaver_new (connection);
-	
+
+        ev_metadata_manager_init ();
+
 	return TRUE;
 }
 #endif /* ENABLE_DBUS */
@@ -148,8 +156,6 @@ ev_application_register_service (EvApplication *application)
 EvApplication *
 ev_application_get_instance (void)
 {
-	static EvApplication *instance;
-
 	if (!instance) {
 		instance = EV_APPLICATION (g_object_new (EV_TYPE_APPLICATION, NULL));
 	}
@@ -731,8 +737,15 @@ ev_application_shutdown (EvApplication *application)
 	}
 #endif /* ENABLE_DBUS */
 	
+        ev_metadata_manager_shutdown ();
+
+        g_free (application->dot_dir);
+        application->dot_dir = NULL;
 	g_free (application->last_chooser_uri);
+        application->last_chooser_uri = NULL;
+
 	g_object_unref (application);
+        instance = NULL;
 	
 	gtk_main_quit ();
 }
@@ -750,6 +763,15 @@ ev_application_init (EvApplication *ev_application)
 	
 	ev_application_init_session (ev_application);
 
+        ev_application->dot_dir = g_build_filename (g_get_home_dir (),
+                                                    ".gnome2",
+                                                    "evince",
+                                                    NULL);
+
+        /* FIXME: why make this fatal? */
+        if (!ev_dir_ensure_exists (ev_application->dot_dir, 0700))
+                exit (1);
+
 	home_dir = g_get_home_dir ();
 	if (home_dir) {
 		ev_application->accel_map_file = g_build_filename (home_dir,
@@ -763,7 +785,7 @@ ev_application_init (EvApplication *ev_application)
 	ev_application->toolbars_model = egg_toolbars_model_new ();
 
 	ev_application->toolbars_file = g_build_filename
-			(ev_dot_dir (), "evince_toolbar.xml", NULL);
+			(ev_application->dot_dir, "evince_toolbar.xml", NULL);
 
 	egg_toolbars_model_load_names (ev_application->toolbars_model,
 				       DATADIR "/evince-toolbar.xml");
@@ -893,7 +915,7 @@ ev_application_get_print_settings_file (EvApplication *application)
 
 	application->print_settings_file = g_key_file_new ();
 	
-	filename = g_build_filename (ev_dot_dir (), EV_PRINT_SETTINGS_FILE, NULL);
+	filename = g_build_filename (ev_application_get_dot_dir (application), EV_PRINT_SETTINGS_FILE, NULL);
 	if (g_file_test (filename, G_FILE_TEST_IS_REGULAR)) {
 		GError *error = NULL;
 
@@ -934,7 +956,7 @@ ev_application_save_print_settings (EvApplication *application)
 					    key_file,
 					    EV_PAGE_SETUP_GROUP);
 	
-	filename = g_build_filename (ev_dot_dir (), EV_PRINT_SETTINGS_FILE, NULL);
+	filename = g_build_filename (ev_application_get_dot_dir (application), EV_PRINT_SETTINGS_FILE, NULL);
 	data = g_key_file_to_data (key_file, (gsize *)&data_length, NULL);
 	g_file_set_contents (filename, data, data_length, &error);
 	if (error) {
@@ -1022,3 +1044,9 @@ ev_application_set_page_setup (EvApplication *application,
 	application->page_setup = g_object_ref (page_setup);
 	gtk_page_setup_to_key_file (page_setup, key_file, EV_PAGE_SETUP_GROUP);
 }
+
+const gchar *
+ev_application_get_dot_dir (EvApplication   *application)
+{
+	return application->dot_dir;
+}
